var NAVTREEINDEX20 =
{
"structpw__stream__events.html#a4d1ed03aa78fb2c8324ae13bc45731e3":[10,0,4,5],
"structpw__stream__events.html#a512bd219ce44ba1a688d600773efe84b":[10,0,4,8],
"structpw__stream__events.html#a66e43e35eb2be261520cda8a4e24098c":[10,0,4,10],
"structpw__stream__events.html#a74aaca4c31e44dad69aba50607055419":[10,0,4,0],
"structpw__stream__events.html#a89192aed5fcd89314bf7cc7ef6b21085":[10,0,4,2],
"structpw__stream__events.html#aab4b9831ef563920b401b1f9daf93042":[10,0,4,9],
"structpw__stream__events.html#abbe98bb0d78e6411d08244495f349b0b":[10,0,4,1],
"structpw__stream__events.html#abd09d7c76b0e14a201a438f09e609b29":[10,0,4,6],
"structpw__stream__events.html#ad60b819ff0ea17b0bd8833220cbd4a3e":[10,0,4,4],
"structpw__thread__loop.html":[10,5,15,2],
"structpw__thread__loop__events.html":[10,5,15,1],
"structpw__thread__loop__events.html#a3c806806a4d07a0b3735f4b625740652":[10,5,15,1,1],
"structpw__thread__loop__events.html#a6815fa728af5ab602c111e7c5b680387":[10,5,15,1,0],
"structpw__time.html":[10,0,3],
"structpw__time.html#a1ea3fa77ce4221df0d5ac3ad8fd1f6c7":[10,0,3,3],
"structpw__time.html#a41d793c390eefc6aee165e16e0d7c898":[10,0,3,1],
"structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff":[10,0,3,5],
"structpw__time.html#a91dafbb38397328f8705e2bb20b7625a":[10,0,3,4],
"structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d":[10,0,3,6],
"structpw__time.html#a99e3d7963e24fbf410afa03c73465328":[10,0,3,2],
"structpw__time.html#ad817da21bea1591d70f837c251a73468":[10,0,3,0],
"structpw__time.html#aebd42745267531bc23e1ee34dd759607":[10,0,3,7],
"structpw__work__queue.html":[10,5,16,1],
"structpwtest__context.html":[10,2,2],
"structpwtest__spa__plugin.html":[10,2,1],
"structpwtest__spa__plugin.html#a22553184b5d864e926e17d976cffca9f":[10,2,1,2],
"structpwtest__spa__plugin.html#a8bb79b9b0e5cb045fa2686edde9c3d34":[10,2,1,5],
"structpwtest__spa__plugin.html#ad517984d1206a29ad28eb83f19f41dbe":[10,2,1,0],
"structpwtest__spa__plugin.html#adc8a853d256b3dca56a3e805dc96c5b4":[10,2,1,3],
"structpwtest__spa__plugin.html#ae819473de8479871a6cd78f10a97ce68":[10,2,1,1],
"structpwtest__spa__plugin.html#aef8a87ec887314f7a70366be56138406":[10,2,1,4],
"structpwtest__suite.html":[10,2,3],
"structpwtest__test.html":[10,2,4],
"structspa__audio__aec.html":[11,0,138],
"structspa__audio__aec.html#a09e1e6ddb6cba06861e418fad8eb2442":[11,0,138,1],
"structspa__audio__aec.html#a2c343b0ced8bc8a9d22c441558c1cc9f":[11,0,138,2],
"structspa__audio__aec.html#a472c09f9a147170d0892a650b60c9b5d":[11,0,138,0],
"structspa__audio__aec__events.html":[11,0,139],
"structspa__audio__aec__events.html#a355f3bedb9b4094912577187225797d9":[11,0,139,1],
"structspa__audio__aec__events.html#ab137f922d3a547caf388c5c11be2e5ce":[11,0,139,0],
"structspa__audio__aec__info.html":[11,0,140],
"structspa__audio__aec__info.html#a88dbf8b905a3f808af985764cb21fd7c":[11,0,140,0],
"structspa__audio__aec__methods.html":[11,0,141],
"structspa__audio__aec__methods.html#a028adaf84c4fb5c19e416c53874ad57f":[11,0,141,8],
"structspa__audio__aec__methods.html#a0e357608392e4e4cf8224a523882a80c":[11,0,141,1],
"structspa__audio__aec__methods.html#a0ea3331fe5e9ceed6a0969c4f2aaa4c3":[11,0,141,4],
"structspa__audio__aec__methods.html#a1d1c3a7ec1bd783ddb3cea31bc421cb1":[11,0,141,6],
"structspa__audio__aec__methods.html#a5b18f9a4430576c06bf7067a61a97854":[11,0,141,5],
"structspa__audio__aec__methods.html#a73977fea4b6c069260af4f16b08ceee0":[11,0,141,10],
"structspa__audio__aec__methods.html#aa75447be29ace8e48fefb525ed44bcd8":[11,0,141,7],
"structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d":[11,0,141,3],
"structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,141,0],
"structspa__audio__aec__methods.html#af75957ae10a92bb2253df67aa6eca97f":[11,0,141,9],
"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,141,2],
"structspa__audio__info.html":[10,8,7,34],
"structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[10,8,7,34,5],
"structspa__audio__info.html#a0c0ba9b2cb3625fdbfa3a5f1a00639d3":[10,8,7,34,16],
"structspa__audio__info.html#a1042e506082d62d0c5371c3d9d349a9a":[10,8,7,34,8],
"structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[10,8,7,34,3],
"structspa__audio__info.html#a41f273519b13112d24c1a7066755e3d8":[10,8,7,34,11],
"structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75":[10,8,7,34,1],
"structspa__audio__info.html#a5d87c4474c9eb1a61153dd460599591b":[10,8,7,34,6],
"structspa__audio__info.html#a635122b47bf1de20dd009ecca6cdb7d3":[10,8,7,34,10],
"structspa__audio__info.html#a755a925f66d28b0e9912482e97375b7a":[10,8,7,34,2],
"structspa__audio__info.html#a880d36c25907b88e7ca3dc34d200c343":[10,8,7,34,15],
"structspa__audio__info.html#a9128e8bd148abec71d6261dc5af9a7d9":[10,8,7,34,14],
"structspa__audio__info.html#a9782c7a01047c3a1058fd8dd40c5f52b":[10,8,7,34,7],
"structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30":[10,8,7,34,0],
"structspa__audio__info.html#aa02a98d24c25c529d6b387ed1eb7074e":[10,8,7,34,4],
"structspa__audio__info.html#ab9bbd067632a6e02f042dacff838c89b":[10,8,7,34,9],
"structspa__audio__info.html#add88e2561d596e2d9d79bf772c7c6972":[10,8,7,34,12],
"structspa__audio__info.html#ae9fd0fa99badc8be9ce0e59bb75f31f9":[10,8,7,34,13],
"structspa__audio__info__aac.html":[11,0,143],
"structspa__audio__info__aac.html#a16974760cfa2cbe91398d01fb7f4b947":[11,0,143,1],
"structspa__audio__info__aac.html#a3b08334e341344e0035a7ee94a5c87a2":[11,0,143,2],
"structspa__audio__info__aac.html#ab29a8d8e1cba013ab5008404ba2836ea":[11,0,143,0],
"structspa__audio__info__aac.html#ad93ec0c832f6ed449d9e073068e221d1":[11,0,143,3],
"structspa__audio__info__alac.html":[11,0,144],
"structspa__audio__info__alac.html#a93d94a062b877bdb495bd1b07364f05d":[11,0,144,0],
"structspa__audio__info__alac.html#afd38ff2d76cd8078e80f8955dc23da19":[11,0,144,1],
"structspa__audio__info__amr.html":[11,0,145],
"structspa__audio__info__amr.html#a1b1d2870fa166b3de6bf2f5b1b45a05d":[11,0,145,1],
"structspa__audio__info__amr.html#a42ebba3d8e2cdd474ef49fb4c4c6b0f4":[11,0,145,2],
"structspa__audio__info__amr.html#ac715c7089e6ff2b562a3762bd46136cb":[11,0,145,0],
"structspa__audio__info__ape.html":[11,0,146],
"structspa__audio__info__ape.html#a72509a439dfbe203c6c3653bed2153ed":[11,0,146,0],
"structspa__audio__info__ape.html#a82e8f9bb5e9bd7bd014a92709a06b9f9":[11,0,146,1],
"structspa__audio__info__dsd.html":[10,8,7,33],
"structspa__audio__info__dsd.html#a4f11fce0402edcbe61f0b35f27396ac9":[10,8,7,33,5],
"structspa__audio__info__dsd.html#a563add98a612fe3617a58e2cb1a703bc":[10,8,7,33,4],
"structspa__audio__info__dsd.html#a698a141255b6d57f04d56de0fa52d170":[10,8,7,33,0],
"structspa__audio__info__dsd.html#a72a8060d8747abb6e380e0dc0261157e":[10,8,7,33,3],
"structspa__audio__info__dsd.html#a902dd094aab140dc3500a3a36ef967da":[10,8,7,33,2],
"structspa__audio__info__dsd.html#a9f7ed724310d9b5a2c95607399fe3a34":[10,8,7,33,1],
"structspa__audio__info__dsp.html":[11,0,148],
"structspa__audio__info__dsp.html#ab59df8be3387df377c8b698346aa234f":[11,0,148,0],
"structspa__audio__info__flac.html":[11,0,149],
"structspa__audio__info__flac.html#a3351a0cbf04538db70fac13cd630e79e":[11,0,149,1],
"structspa__audio__info__flac.html#a9be31890542f5995b7bbe493cd29f688":[11,0,149,0],
"structspa__audio__info__iec958.html":[10,8,7,35],
"structspa__audio__info__iec958.html#ab4797480f2e4e7f25d19a0a42c748eac":[10,8,7,35,1],
"structspa__audio__info__iec958.html#adc76e7bde0fc3d66ffa5a8442c3b1409":[10,8,7,35,0],
"structspa__audio__info__iec958.html#af028b6675757cd4504ad1b11a2e746c7":[10,8,7,35,2],
"structspa__audio__info__mp3.html":[11,0,151],
"structspa__audio__info__mp3.html#a2066d86c3d391a097c57441f8c391234":[11,0,151,0],
"structspa__audio__info__mp3.html#a9eab81f1ef553124803e7563d7ffce93":[11,0,151,1],
"structspa__audio__info__opus.html":[11,0,152],
"structspa__audio__info__opus.html#ab354cfeab8ed9e4561332f86f77f5397":[11,0,152,1],
"structspa__audio__info__opus.html#abf65d8f7d0877d50068bb68cff1f3e44":[11,0,152,0],
"structspa__audio__info__ra.html":[11,0,153],
"structspa__audio__info__ra.html#a281cd0f54656e1ccfda03854e5d36ce2":[11,0,153,1],
"structspa__audio__info__ra.html#aa5374f33cf4a773ca3bb779d3e199fc9":[11,0,153,0],
"structspa__audio__info__raw.html":[10,8,7,37],
"structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[10,8,7,37,0],
"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[10,8,7,37,3],
"structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[10,8,7,37,1],
"structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[10,8,7,37,4],
"structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[10,8,7,37,2],
"structspa__audio__info__vorbis.html":[11,0,155],
"structspa__audio__info__vorbis.html#a7614ad24e4491223d0d44c1931c3089b":[11,0,155,0],
"structspa__audio__info__vorbis.html#afec5882d3af8e9d177b4b0771c176046":[11,0,155,1],
"structspa__audio__info__wma.html":[11,0,156],
"structspa__audio__info__wma.html#a08102a7049195a3a9f5b734a6b8f7be5":[11,0,156,1],
"structspa__audio__info__wma.html#a0bf6e6bad02abf194f2d65b5b458e7ba":[11,0,156,4],
"structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55":[11,0,156,3],
"structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2":[11,0,156,2],
"structspa__audio__info__wma.html#ad572e9079c943a87b18d96060ced5af4":[11,0,156,0],
"structspa__audio__layout__info.html":[10,8,7,36],
"structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[10,8,7,36,1],
"structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[10,8,7,36,0],
"structspa__buffer.html":[10,8,1,7],
"structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[10,8,1,7,0],
"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[10,8,1,7,2],
"structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560":[10,8,1,7,3],
"structspa__buffer.html#adbf5510ef0707e22b19980c84b61a073":[10,8,1,7,1],
"structspa__buffer__alloc__info.html":[10,8,1,4],
"structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6":[10,8,1,4,11],
"structspa__buffer__alloc__info.html#a30233569ad362f458d9e1344d0b5a58c":[10,8,1,4,10],
"structspa__buffer__alloc__info.html#a49810ff55f219eea5c1e4a3e2f24cd4c":[10,8,1,4,2],
"structspa__buffer__alloc__info.html#a51af051b079634c3f854680f118716e7":[10,8,1,4,1],
"structspa__buffer__alloc__info.html#a63296028aeb53c2e98501c78f1d53617":[10,8,1,4,8],
"structspa__buffer__alloc__info.html#a8ea4df582a468b0f1621672af3e2426f":[10,8,1,4,9],
"structspa__buffer__alloc__info.html#a963cf1755ba6612abcff0491680abc64":[10,8,1,4,7],
"structspa__buffer__alloc__info.html#adea010a789fec41087739852b235185b":[10,8,1,4,5],
"structspa__buffer__alloc__info.html#ae0f8e64c4f71c63cfa87b1b7527a47c7":[10,8,1,4,6],
"structspa__buffer__alloc__info.html#aea2d60a678ae26619b5bfb35291b9a01":[10,8,1,4,3],
"structspa__buffer__alloc__info.html#aef6e15022383cf49cbba4196111c190d":[10,8,1,4,4],
"structspa__buffer__alloc__info.html#afc286a004cefa1ef2d751483a8cc8c15":[10,8,1,4,0],
"structspa__callbacks.html":[10,8,8,5,1],
"structspa__callbacks.html#a0c52caccee37692f842b93785b3f7f22":[10,8,8,5,1,0],
"structspa__callbacks.html#adc0097ae82d42b5fc92e896f47e13ee5":[10,8,8,5,1,1],
"structspa__chunk.html":[10,8,1,5],
"structspa__chunk.html#a5a6f66c73b76acf608ef18846d539df2":[10,8,1,5,2],
"structspa__chunk.html#a73c84537a6f3a0da168f765cb3558735":[10,8,1,5,1],
"structspa__chunk.html#ae77eb3c5ecf94cc2b80c306afd7a6768":[10,8,1,5,3],
"structspa__chunk.html#ae7a889b81a5d56ff5babd521b5ce7cb7":[10,8,1,5,0],
"structspa__command.html":[10,8,0,13],
"structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e":[10,8,0,13,1],
"structspa__command.html#ad422c2065f2080f39a1ee42b77154c55":[10,8,0,13,0],
"structspa__command__body.html":[10,8,0,12],
"structspa__command__body.html#ab477c03f242e4d10ed2a4e7057f52123":[10,8,0,12,0],
"structspa__cpu.html":[10,8,9,0,1],
"structspa__cpu.html#a4822c09d9eb0c57ca8d7b6e8ed4bfcda":[10,8,9,0,1,0],
"structspa__cpu__methods.html":[10,8,9,0,2],
"structspa__cpu__methods.html#a269e1e0cff0d3674d92b9d4935089aa8":[10,8,9,0,2,4],
"structspa__cpu__methods.html#a52a1db59dcb261cd6348733232932a66":[10,8,9,0,2,2],
"structspa__cpu__methods.html#a700fe283edbd95218d18e6c5cac7f327":[10,8,9,0,2,3],
"structspa__cpu__methods.html#a705910a6b831fd551b298ad64182598f":[10,8,9,0,2,1],
"structspa__cpu__methods.html#ac728f1a2d9783599229e2e55cc6b0902":[10,8,9,0,2,6],
"structspa__cpu__methods.html#acd636f83ca2db246adfc92fc7d669204":[10,8,9,0,2,5],
"structspa__cpu__methods.html#afc8c065c16934356a464235e38aae666":[10,8,9,0,2,0],
"structspa__data.html":[10,8,1,6],
"structspa__data.html#a2ac8186060605f0c2e23d383dc702c18":[10,8,1,6,6],
"structspa__data.html#a504188801211b4dcaae3fc2e37653752":[10,8,1,6,2],
"structspa__data.html#a75b63dcf6ea09c5908b8682f1696eeae":[10,8,1,6,3],
"structspa__data.html#a997e0a03014d4455fbb993c0d7aa0c82":[10,8,1,6,1],
"structspa__data.html#ac4930c9bcfff1327bc57c27a436f6451":[10,8,1,6,5],
"structspa__data.html#ae942ee4f53c1ae2b708fdea5aa334406":[10,8,1,6,4],
"structspa__data.html#afe135d90bee247325e72ba2f33dd9864":[10,8,1,6,0],
"structspa__dbus.html":[10,8,9,1,1],
"structspa__dbus.html#a240c318013b1a4441195fa94f213b65b":[10,8,9,1,1,0],
"structspa__dbus__connection.html":[10,8,9,1,3],
"structspa__dbus__connection.html#a1b0a0400c311d50b764f100b4b50bf8f":[10,8,9,1,3,2],
"structspa__dbus__connection.html#a2e21fc21219047d9bdc8e1994a23acea":[10,8,9,1,3,3],
"structspa__dbus__connection.html#a684f175f4839121d8c976c50ca273303":[10,8,9,1,3,1],
"structspa__dbus__connection.html#a8b89c910cd288a5e1d2af8216568a3a6":[10,8,9,1,3,0],
"structspa__dbus__connection__events.html":[10,8,9,1,2],
"structspa__dbus__connection__events.html#a1e35b4f490157dd9c4194b4a03490fc6":[10,8,9,1,2,1],
"structspa__dbus__connection__events.html#a2ae8b95b36226127853160f1779260e0":[10,8,9,1,2,0],
"structspa__dbus__connection__events.html#a481b39049a46ec7d8519c8d2c9318968":[10,8,9,1,2,2],
"structspa__dbus__methods.html":[10,8,9,1,4],
"structspa__dbus__methods.html#a1e518bcb13046ec6b46a927024b6cc28":[10,8,9,1,4,1],
"structspa__dbus__methods.html#a6e090fa6083fa425460f631ea48c3434":[10,8,9,1,4,0],
"structspa__debug__context.html":[10,8,3,9],
"structspa__debug__context.html#a5d5a27395a63043da36af7b1289cc711":[10,8,3,9,0],
"structspa__debug__log__ctx.html":[10,8,3,10],
"structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724":[10,8,3,10,6],
"structspa__debug__log__ctx.html#a49ae612d5a9f8abff00d338e0f42f338":[10,8,3,10,5],
"structspa__debug__log__ctx.html#a7834e2a074032895d9760015da193685":[10,8,3,10,1],
"structspa__debug__log__ctx.html#a7ef044cf8f043c056c0f09e7dc52772f":[10,8,3,10,2],
"structspa__debug__log__ctx.html#a89c265ff2c1860bc78cb3a71e016c44a":[10,8,3,10,0],
"structspa__debug__log__ctx.html#abcfc47fb7d6acf39603b9a1547edd1e7":[10,8,3,10,4],
"structspa__debug__log__ctx.html#afcdc7fd8504c905b64485893b6816ee2":[10,8,3,10,3],
"structspa__device.html":[10,8,4,3],
"structspa__device.html#a00d8f19734c35525e99ecaab33113d3f":[10,8,4,3,0],
"structspa__device__events.html":[10,8,4,7],
"structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3":[10,8,4,7,2],
"structspa__device__events.html#a5b83e45fd5922657978cc36df24cc1c7":[10,8,4,7,3],
"structspa__device__events.html#a64cea4459b8c4a483d0a2dd684f3e132":[10,8,4,7,1],
"structspa__device__events.html#a830fadb39e2a8658f9b4cb663619cf4b":[10,8,4,7,4],
"structspa__device__events.html#ad79a5bdce6b6bd7b299baa38330c96a7":[10,8,4,7,0],
"structspa__device__info.html":[10,8,4,4],
"structspa__device__info.html#a2692374f54a8d9f743474c4a3fcb8ebc":[10,8,4,4,2],
"structspa__device__info.html#a2ef8690873a8db10e6c29357ea4a216c":[10,8,4,4,3],
"structspa__device__info.html#a394aa2b1d356ce8e510330aedd38ff63":[10,8,4,4,0],
"structspa__device__info.html#a5184282839436a8b87d505b4b17cffbd":[10,8,4,4,4],
"structspa__device__info.html#afbe429acf565ab384929f0ccf76fc49c":[10,8,4,4,1],
"structspa__device__methods.html":[10,8,4,8],
"structspa__device__methods.html#a232006e407b2abdb2450a440172186ee":[10,8,4,8,0],
"structspa__device__methods.html#a25f49777c2e75988cd5fd7fc490479c8":[10,8,4,8,2],
"structspa__device__methods.html#a3c9741ff5de62f38f2e3eca50ae24a10":[10,8,4,8,3],
"structspa__device__methods.html#aa5bfc95e88b2f018dddc55fb64899215":[10,8,4,8,4],
"structspa__device__methods.html#aac8a0ceced3319473ab3edd4271e1d64":[10,8,4,8,1],
"structspa__device__object__info.html":[10,8,4,5],
"structspa__device__object__info.html#a0758afd0518197c48d5d76cdc14526e3":[10,8,4,5,0],
"structspa__device__object__info.html#a4ed767ff310d6f2e1d4cd78f3a7c3f6f":[10,8,4,5,1],
"structspa__device__object__info.html#a702111c5873243c93551073552863666":[10,8,4,5,3],
"structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1":[10,8,4,5,2],
"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0":[10,8,4,5,4],
"structspa__dict.html":[10,8,8,2,2],
"structspa__dict.html#a1f1083da3fcd51b9c3eb22cc8f1d54e0":[10,8,8,2,2,2],
"structspa__dict.html#a3b3b78bfe5fffe13a10720bb7099c399":[10,8,8,2,2,1],
"structspa__dict.html#a88aca003fcdbc47599ffb3e2737f1a69":[10,8,8,2,2,0],
"structspa__dict__item.html":[10,8,8,2,1],
"structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a":[10,8,8,2,1,0],
"structspa__dict__item.html#af08479e3ff870039be002b436a02457d":[10,8,8,2,1,1],
"structspa__dll.html":[11,0,180],
"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[11,0,180,2],
"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[11,0,180,1],
"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[11,0,180,6],
"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[11,0,180,3],
"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[11,0,180,4],
"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[11,0,180,0],
"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[11,0,180,5],
"structspa__event.html":[10,8,0,15],
"structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb":[10,8,0,15,1],
"structspa__event.html#a2411141eed88d3587687a8d86c99d488":[10,8,0,15,0],
"structspa__event__body.html":[10,8,0,14],
"structspa__event__body.html#aa484bc2cadd16a104476183666de3819":[10,8,0,14,0],
"structspa__fraction.html":[10,8,8,1,4]
};
